---
title: 简介
---

## Solana是什么？

Solana是一个开源项目，它实现了一个全新的高性能无许可区块链。 Solana基金会位于瑞士日内瓦，维护着开源项目。

## 为什么需要Solana？

如果平均每个交易不超过176个字节，则标准数据库可能每秒可以处理710,000个交易。 中心化数据库还可以使用称为Optimistic Concurrency Control[\[H.T.Kung, J.T.Robinson (1981)\]](http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.65.4735)的分布式系统技术来复制自身并保持高可用性，而不会显着损害交易处理速率。 在Solana，我们证明了这些相同的理论极限同样适用于对抗网络上的区块链。 关键点在哪里？ 当节点无法彼此信任时，我们找到了一种共享时间的方法。 一旦节点可以相互信任，40年的分布式系统研究经验就可以应用于区块链了！

> 也许我们的方法与基于超时(timeout) 算法之间最显着的区别是，使用超时会产生一种传统的分布式算法，其中进程异步运行，而我们的方法产生一种全局同步的算法，其中每个进程在同一时刻都执行相同的操作。 我们的方法似乎与分布式处理的整个目的相矛盾，后者旨在允许不同的进程独立运行并执行不同的功能。 但是，如果分布式系统实际上是单个系统，则必须以某种方式同步进程。 从概念上讲，同步流程的最简单方法是让所有流程同时执行相同的操作。 因此，我们的方法用于实现和执行必要同步的内核——例如，确保两个不同的进程不会尝试在同一时间修改文件。 进程可能只花费一小部分时间来执行同步内核；在其余时间里，它们可以独立运行——例如访问不同的文件。 即使在不需要容错的情况下，这也是我们提倡的一种方法。 该方法的基本简单性使其更易于理解系统的精确属性，这对于了解系统的容错能力至关重要。 [\[L.Lamport (1984)\]](http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.71.1078)

此外，令我们惊讶的是，它可以使用从第一天开始就存在于比特币中的一种机制来实现。 比特币功能称为nLocktime，它可用于使用区块高度而不是时间戳记来对交易进行排序。 作为比特币客户端，如果您不信任网络，则可以使用区块高度而不是时间戳。 事实证明，区块高度是密码学界所谓的“可验证延迟功能”的一个实例。 这是一种表示时间已过去的加密安全方法。 在Solana中，我们使用更细粒度的可验证延迟函数SHA 256哈希链来检查并协调共识。 有了它，我们实现了乐观并发控制，现在正朝着每秒710,000个事务的理论极限迈进。

## 文件概述

Solana文档描述了Solana开源项目，这是一个从头开始大规模构建的区块链。 它们涵盖了Solana可用的原因，使用方法，工作原理以及即使Solana倒闭以后，很长一段时间内它将继续工作。 Solana架构的目标是证明了存在一套软件算法，当结合使用这些算法来实现区块链时，它消除了软件的性能瓶颈，使交易吞吐量与网络带宽成比例扩展。 该架构继续满足适当区块链的所有三个理想特性：可扩展、安全性和去中心化。

该体系结构描述了标准千兆位网络上每秒71万笔交易 \(tps\) 的理论上限，而40GB上每秒2840万tps的交易上限。 此外，该体系结构支持安全，并发地执行以通用编程语言（例如C或Rust）编写的程序。

## 什么是 Solana 集群？

群集是一组可以协同工作的计算机，可以从外部将其视为单个系统。 Solana集群是一组相互独立的计算机，这些计算机一起工作(有时互相冲突)，以验证用户提交的不可信程序输出。 只要用户希望及时保留事件的不变记录或这些事件的程序解释，就可以利用Solana集群。 一种用途是跟踪哪些计算机做了有意义的工作来保持群集运行。 另一个用途可能是跟踪对现实世界资产的拥有权。 在每种情况下，集群都会生成一个称为账本的事件记录。 它将在群集的整个生命周期内保留。 只要世界上某个地方的某人维护了的副本，其程序的输出\(可能包含谁拥有什么的记录\) 将永远是可复制的，而与发起它的组织无关。

## 什么是SOL？

SOL是Solana原生代币的名称，可以将其传递给Solana集群中的节点，以换取运行链上程序或验证其输出。 系统可以执行分数SOL的微支付，称为_lamports_。 它们的名称是为了纪念Solana的最大技术影响力[Leslie Lamport](https://en.wikipedia.org/wiki/Leslie_Lamport)。 1 Lamport的值为0.000000001 SOL。

## 免责声明

本项目中描述的所有索赔、内容、设计、算法、预估、路线图、规格和性能度量均由作者尽力而为。 读者应检查并验证其准确性和真实性。 此外，该项目中的任何内容都不构成投资的行为。
