---
title: 质押账户结构
---

Solana上的质押账户可用于将代币委托给网络上的验证节点，从而有可能为质押账户的所有者赚取奖励。 质押账户的创建和管理与传统的钱包地址（称为*系统账户*）不同。  系统帐户只能从网络上的其他帐户发送和接收SOL，而质押帐户需要管理代币委托等更复杂的操作。

Solana上的质押账户的运作方式也可能与您可能熟悉的其他权益证明区块链网络不同。  本文档描述了Solana质押账户的高级结构和功能。

#### 帐户地址
每个质押帐户都有一个唯一的地址，可用于在命令行或任何网络浏览器工具中查找帐户信息。  但是，与其中地址的“密钥对”的持有者控制该钱包的钱包地址不同，与质押账户地址相关联的“密钥对”不一定对该帐户具有任何控制权。  实际上，对于质押账户的地址，甚至可能不存在密钥对或私钥。

质押账户的地址唯一具有密钥对文件的时间是当[使用命令行工具创建质押账户](../cli/delegate-stake.md#create-a-stake-account)时，一个新的密钥对文件被首次创建，仅仅是为了确保质押帐户的地址是新的且唯一的。

#### 理解帐户授权
某些类型的帐户可能具有与给定帐户相关联的一个或多个*签名授权*。 帐户授权用于为其控制的帐户签署某些交易。  这与其他一些区块链网络不同，在其他区块链网络中，与账户地址关联的密钥对的持有者控制着账户的所有活动。

每个质押账户都有两个由其各自地址指定的签名授权，每个授权均被授权对质押账户执行某些操作。

*质押授权*用于签署以下操作的交易：
 - 委托质押
 - 停用质押委托
 - 分割质押账户，创建一个新的质押账户，其中第一个账户中有一部分资金
 - 将两个未授权的质押账户合并为一个
 - 设置新的质押授权

*提款授权*对以下各项交易签名：
 - 将未委托的质押提取到钱包地址中
 - 设置新的提款权限
 - 设置新的质押授权

在创建质押账户时，将设置质押授权和提取权限，并且可以随时更改它们以授权新的签名地址。 抵押和提款授权可以是相同的地址，也可以是两个不同的地址。

由于清算质押账户中的代币需要撤回授权密钥对，因此可以更好地控制该帐户，并且如果质押授权密钥对丢失或受到破坏，则可以用来重置质押授权。

在管理质押账户时，确保提取权限不丢失或被盗是至关重要的。

#### 多份委托
每个质押帐户一次只能用于委托一个验证节点。 帐户中的所有代币都是已委托或未委托的，或者正在被委托或未委托的过程中。  要将代币的一部分委托给验证节点，或委托给多个验证节点，您必须创建多个质押账户。

这可以通过从包含一些代币的钱包地址创建多个质押账户来完成，或者通过创建一个大型质押账户，并使用质押授权将帐户拆分为具有您选择的代币余额的多个账户来实现。

可以将相同的质押和提款授权分配给多个质押账户。

可以将两个未委托的，具有相同权限和锁定的质押账户合并为一个质押账户。

#### 委托预热和冷却
当委托质押帐户或取消委托时，该操作不会立即生效。

委托或停用会花费几个[epoch](../terminology.md#epoch)，在将包含指令的交易提交给集群之后，一部分委托在每个epoch边界处变为活动或非活动状态。

在单个epoch内可以委托或取消激活的总质押数也有限制，以防止整个网络上的质押发生突然的大变化。 由于预热和冷却取决于其他网络参与者的行为，因此它们的确切持续时间很难预测。 关于预热和冷却时间的详细信息请参看 [这里](../cluster/stake-delegation-and-rewards.md#stake-warmup-cooldown-withdrawal)。

#### 锁定
质押账户可以进行锁定，以防止持有的代币在到达特定日期或时代之前被提取。  账户锁定后，仍可以委托，解除授权，或拆分质押帐户，并且可以正常更改其质押和提取权限。  只有提现到钱包地址是不允许的。

锁定只能在首次创建质押账户时添加，以后可以由*锁定权限*或*托管人*对其进行修改，而锁定地址也将在创建账户时进行设置。

#### 销毁质押账户
与Solana网络上的其他类型的帐户一样，网络不再跟踪余额为零的SOL质押帐户。  如果未委托一个质押账户，并且其中包含的所有代币都被提取到一个钱包地址，则该地址上的账户将被有效销毁，并且需要手动重新创建该地址才能再次被使用。

#### 查看质押账户
通过将帐户地址复制并粘贴到搜索栏中，可以在 Solana 浏览器上查看质押帐户详细信息。
 - http://explorer.solana.com/accounts
